@@ -23,8 +23,8 @@ class PTRCalibration:
     def extract_data(self):
         for file in self.file_list:
             try:
-                read = pd.read_excel(file, sheet_name=0, header=None).dropna(how="all")
-                read = read.rename(columns=read.iloc[0]).drop(read.index[0])
+                read = pd.read_excel(file, sheet_name=0).dropna(how="all")
+                read['Log File'] = os.path.splitext(os.path.split(file)[-1])[0]
                 self.frames.append(read)
             except PermissionError:
                 self.permission.append(os.path.split(file)[-1].split("_")[0])
